@@ -1,28 +1,26 @@
 """Special handler for modifier."""
-from typing import TYPE_CHECKING, Optional
+from __future__ import annotations
+
+from typing import TYPE_CHECKING
 
 from ..strategy import VERSION_STRATEGIES_DICT, AwesomeVersionStrategy
 from ..utils.regex import RE_MODIFIER
 
-SEMVER_MODIFIER_MAP = {"alpha": 1, "beta": 2, "rc": 3}
+SEMVER_MODIFIER_MAP = {"dev": 0, "alpha": 1, "beta": 2, "rc": 3}
 
 if TYPE_CHECKING:
     from awesomeversion import AwesomeVersion
 
 
 def compare_handler_semver_modifier(
-    version_a: "AwesomeVersion",
-    version_b: "AwesomeVersion",
-) -> Optional[bool]:
+    version_a: AwesomeVersion,
+    version_b: AwesomeVersion,
+) -> bool | None:
     """Compare handler sections."""
-    if (
-        AwesomeVersionStrategy.SEMVER
-        not in (
-            version_a.strategy,
-            version_b.strategy,
-        )
-        or (version_a.modifier_type is None or version_b.modifier_type is None)
-    ):
+    if AwesomeVersionStrategy.SEMVER not in (
+        version_a.strategy,
+        version_b.strategy,
+    ) or (version_a.modifier_type is None or version_b.modifier_type is None):
         return None
 
     if version_a.modifier_type != version_b.modifier_type:
